OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Limite de descarga de ficheiros",
    "Limit downloads" : "Limitar descargas",
    "Set download limit" : "Definir limite de descargas",
    "Download limit" : "Limite de transferência",
    "You have reached the maximum amount of downloads allowed" : "Atingiu o número máximo de descargas autorizadas",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Esta partilha tem um número limite de descargas. Tem a certeza que quer fazer uma nova descarga?"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
